//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

// ----------------------------------------------------------- 
// Equation of time
//> Equation of time
//> Represents the time difference: (E) = UT minus 'Greenwich solar time' in minutes. 
//> So when it is noon (Greenwich solar time), it is noon+(E) UT. 
// Auteur : A. Lamy
// -----------------------------------------------------------

// eqt = mean local time minus true local time (hours)
function [eqt] = time_equation(year, trel)
  t0 = CL_dat_cal2cjd(year,01,01,0,0,0);
  tab_t = t0 + trel; 
  hlocmoy = 12*ones(tab_t); // mean loc time = 12h
  hlocvraie = CL_op_locTime(tab_t ,'mlh',hlocmoy,'tlh'); // true 
  eqt = hlocmoy - hlocvraie; 
endfunction 

year_ref = 2000; 
year_min = 1950;
year_max = 2050;

trel = 0 : 365;  
years = year_min : 2 : year_max;

[Year, Trel] = ndgrid(years, trel); 
Eqt = matrix(time_equation(matrix(Year,1,-1), matrix(Trel, 1, -1)), size(Year));

eqt_min = min(Eqt , "r"); 
eqt_max = max(Eqt , "r"); 
eqt_ref = time_equation(year_ref, trel); 


// ------------------------------------------
// plot
// ------------------------------------------
f = scf(); 
f.visible = "on"; 
f.immediate_drawing = "off"; 
a = gca();

plot(trel*12/365, eqt_min *60, "b", "thickness", 2); 
plot(trel*12/365, eqt_max *60, "r", "thickness", 2); 
plot(trel*12/365, eqt_ref *60, "k", "thickness", 2); 

txt = msprintf("between %d and %d", year_min, year_max); 
legend(["Min " + txt, "Max " + txt, "2000"]); 

// grid
for i = 0 : 12
  plot2d([i,i], [-20,15], style = 1); 
  h = CL_g_select(gce(), "Polyline"); 
  h.line_style = 3; 
end

a.title.text = "Equation of time"; 
a.y_label.text = "Mean local time minus true local time (min)"; 

month_names = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];

a.x_ticks = tlist(["ticks", "locations", "labels"], 0.5:11.5, month_names); 
CL_g_stdaxes(a);
a.sub_ticks(1) = 0; // no substicks for a-axis 
a.grid = [-1,1]; 
a.grid_position = "background"; 


f.immediate_drawing = "on"; 
f.visible = "on"; 



