//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [C] = CL_addm(A,B)
// Addition of 2 matrices 
//
// Calling Sequence
// C = CL_addm(A, B)
//
// Description
// <itemizedlist><listitem>
// <p>Add 2 matrices (or hypermatrices) with different sizes. </p>
// <p></p>
// <p>The matrices (or hypermatrices) are first expanded so that 
// if the size in one dimension is 1, the values are duplicated to match the maximum 
// size between the 2 matrices (or hypermatrices) in that dimension. </p>
// <p></p>
// <p> If A or B is [], the result is []. </p> 
// <p></p>
// </listitem>
// <listitem>
// <p><b>Notes</b>:</p>
// <p>- The function works for matrices or hypermatrices of any size. </p>
// </listitem>
// </itemizedlist>
//
// Parameters
// A: Matrix or hypermatrix (NxPx... or 1xPx... or Nx1x... etc...)
// B: Matrix or hypermatrix (NxPx... or 1xPx... or Nx1x... etc...)
// C: Result (NxPx...) 
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_dMult
//
// Examples
// // Example 1 
// A = [1, 2, 3];
// B = [4; 5; 6];
// 
// // A + B 
// CL_addm(A, B) // => same as repmat(A, 3, 1) + repmat(B, 1, 3)
// 
// // A - B 
// CL_addm(A, -B) // => same as repmat(A, 3, 1) - repmat(B, 1, 3)
// 
// // Example 2
// u = [1; 0; 0]; 
// v = [[1;0;0], [0;1;0], [0;0;1]]; 
// 
// // u - v
// CL_addm(u, -v)


// Declarations:


// Code:

// resize matrices (and check consistency)
// => resulting matrix have same size (or one at least is []) 
[A, B] = CL__adjustSizes(A, B); 

// Addition
if (A == [] | B == [])
  C = []; 
else
  C = A + B; 
end

endfunction

