//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [c] = CL_stumpC(z)
// Stumpff function C(z)
//
// Calling Sequence
// c = CL_stumpC(z)
//
// Description
// <itemizedlist><listitem>
// <p>Evaluates the Stumpff function C(z) according to the following equation :</p>
// <p><inlinemediaobject><imageobject><imagedata fileref="stumpC.gif"/></imageobject></inlinemediaobject></p>
// </listitem>
// </itemizedlist>
//
// Parameters
// z: input argument (1xN)
// c: value of C(z) (1xN)
//
// Authors
// CNES - DCT/SB
//
// Bibliography
// 1) Orbital Mechanics for engineering students, H D Curtis, Chapter 3 and Appendix D.4
// 2) Modern astrodynamics Fundamentals and perturbation methods, V Bond and M Allman, Chapter 6.2
//
// See also
// CL_stumpS
//
// Examples
// z = -200 : 500;
// c = CL_stumpC(z);
// 
// scf(); 
// plot(z,c);
// a = gca(); 
// a.log_flags = "nln";
//

// Declarations:

// Code:

c = %nan * ones(z);  // CL_stumpC(%nan) = %nan

I = find(z > 0);
if (I <> [])
  c(I) = (1 - cos(sqrt(z(I)))) ./ z(I);
end

I = find(z < 0);
if (I <> [])
  c(I) = (cosh(sqrt(-z(I))) - 1) ./ (-z(I));
end

I = find(z == 0);  
c(I) = 1/2;

endfunction

