//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [s] = CL_stumpS(z)
// Stumpff function S(z)
//
// Calling Sequence
// s = CL_stumpS(z)
//
// Description
// <itemizedlist><listitem>
// <p>Evaluates the Stumpff function S(z) according to the following equation :</p>
// <p><inlinemediaobject><imageobject><imagedata fileref="stumpS.gif"/></imageobject></inlinemediaobject></p>
// </listitem>
// </itemizedlist>
//
// Parameters
// z: input argument (1xN)
// s: value of S(z) (1xN)
//
// Authors
// CNES - DCT/SB
//
// Bibliography
// 1) Orbital Mechanics for engineering students, H D Curtis, Chapter 3 and Appendix D.4
// 2) Modern astrodynamics Fundamentals and perturbation methods, V Bond and M Allman, Chapter 6.2
//
// See also
// CL_stumpC
//
// Examples
// z = -200 : 500;
// c = CL_stumpS(z);
// 
// scf(); 
// plot(z,c);
// a = gca(); 
// a.log_flags = "nln";
//

// Declarations:


// Code:

s = %nan * ones(z);   // CL_stumpC(%nan) = %nan

I = find(z > 0);
if (I <> [])
  s(I) = (sqrt(z(I)) - sin(sqrt(z(I)))) ./ (sqrt(z(I))).^3;
end

I = find(z < 0);
if (I <> [])
s(I) = (sinh(sqrt(-z(I))) - sqrt(-z(I))) ./ (sqrt(-z(I))).^3;
end

I = find(z == 0); 
s(I) = 1/6;

endfunction
