//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

//  Demo tool for CelestLab
//  Author: A. Lamy

// -------------------------------------------------------------
// main
// -------------------------------------------------------------
function [] = CL__demos()

// repertoire "racine des demos"
rep_demos = fullfile(CL_home(), "demos");

// fichier logo CelestLab
nomfic_logo = fullfile(CL_home(), "data", "misc", "logo_celestlab_small.png");

CL__demos_main(rep_demos, nomfic_logo);

endfunction


// -------------------------------------------------------------
// main function
// -------------------------------------------------------------
function CL__demos_main(rep_base, nomfic_logo)

  frame_wl     = 200;     // Frame width (left)
  frame_wr     = 260;     // Frame width (right)
  frame_h      = 220;     // Frame height (left)
  m_x          = 15;      // x margin
  m_y          = 15;      // y margin
  dy_titre     = 30;      
  dy_logo      = 136;     // exact dimension logo y 
  dx_logo      = 121;     // exact dimension logo x
  dy_box       = 20;      // "checkbox" area (< dy_logo)

  dx = [m_x, frame_wl, m_x, frame_wr, m_x];
  dy = [m_y, dy_box, dy_logo - dy_box, m_y, frame_h, dy_titre];

  px = [0,cumsum(dx)];
  py = [0,cumsum(dy)];

  dim = [px($), py($)]; 

  cadre_1 = [ px(2), py(5), dx(2), dy(5)];
  cadre_2 = [ px(4), py(3), dx(4), sum(dy(3:5))];

  cadre_logo = [ px(1), py(1), sum(dx(1:3)), sum(dy(1:4))];
  cadre_box = [ px(4), py(2), 100, dy_box ]; // 200: size along x

  // change default values temporarily
  figdef = gdf(); 
  figdef.figure_position = [20,20]; 
  figdef.figure_size = [100,100]; 

  // no axes
  if (CL__scilabVersion() >= 550)
    fig = figure("Figure_name", "CelestLab Demo Tool", "Tag", "CL_demoTool", ...
               "visible", "off", "default_axes", "off");
  else
    fig = figure("Figure_name", "CelestLab Demo Tool", "Tag", "CL_demoTool", ...
               "visible", "off");
  end  
    
  fig.immediate_drawing = "off";
  fig.background      = -2;

  toolbar(fig.figure_id, "off");
  delmenu(fig.figure_id, gettext("&File"));
  delmenu(fig.figure_id, gettext("&?"));
  delmenu(fig.figure_id, gettext("&Tools"));
  delmenu(fig.figure_id, gettext("&Edit"));

  hm1 = uimenu( "parent", fig, "label" , 'File');
  hm2 = uimenu( "parent", fig, "label" , 'Edit');
  hm3 = uimenu( "parent", fig, "label" , 'Help');

  fig.axes_size = dim;

  uimenu( "parent"    , hm1, ...
          "label"     , 'Quit', ...
          "callback"  , "CL__demos_cb(2)" );

  uimenu( "parent"    , hm2, ...
          "label"     , 'Options ...', ...
          "callback"  , "CL__demos_cb(4)" );

  uimenu( "parent"    , hm3, ...
          "label"     , 'Find a demo (keywords) ...', ...
          "callback"  , "CL__demos_cb(6)" );

  uimenu( "parent"    , hm3, ...
          "label"     , 'Find a demo (CelestLab function calls) ...', ...
          "callback"  , "CL__demos_cb(7)" );

  uimenu( "parent"    , hm3, ...
          "label"     , 'Help ...', ...
          "callback"  , "CL__demos_cb(5)" );

          
  // disable "resize"
  // only from version 5.5
  if (CL__scilabVersion() >= 550)
    fig.resize = "off"; 
  end	
  
  // read data
  [topics, contents] = CL__demos_gen_data(rep_base);

  // list of "topics"
  h1 = CL__demos_createListe(fig, "Topics", cadre_1, "liste1");

  CL__demos_createLogo(fig, nomfic_logo, cadre_logo, dx_logo, dy_logo);

  // list of "applications"
  h2 = CL__demos_createListe(fig, "Applications", cadre_2, "liste2");

  // other options (check boxes)
  h3 = CL__demos_createCheckbox(fig, "Keep Plots", cadre_box, "Keep");
  h4 = CL__demos_createCheckbox(fig, "Show Info", cadre_box+[0,-17,0,0], "View");
  h5 = CL__demos_createCheckbox(fig, "Show script", cadre_box+[150,0,0,0], "Edit");

  cb_actif = 0;      // 1 = call back en cours
  listfen = list();  // list of created windows
  numtopic = 0;      // current topic number
  numchoix = 0;      // current application number
  db_mode = "OFF";   // "ON" of "OFF" (OFF = not active)
  find_opt = "TEXT"; // "TEXT" or "SCRIPT"
  
  // activation
  demo = tlist(['demo', 'topics', 'contents', 'h1', 'h2', 'h3', 'h4', 'h5', 'fig', ...
                'numtopic', 'numchoix', 'listfen', 'cb_actif', 'db_mode', ...
                'find_opt'], ...
                 topics, contents, h1, h2, h3, h4, h5, fig, ...
                 numtopic, numchoix, listfen, cb_actif, db_mode, find_opt);

  set(demo.h1, "string", strcat(topics(:,1),"|"));
  set(demo.h1, "user_data", topics);
  set(demo.h3, "value", 0);
  set(demo.h4, "value", 0);
  set(demo.h5, "value", 0);

  demo.fig.immediate_drawing = "on";
  
  // visible "off" removed because not OK in scilab 5.5 
  // demo.fig.visible = "off"; // to be sure that no plot can appear in the plot

  demo.cb_actif = 0; // 1 = call back en cours
  demo.listfen = list();

  set(fig,"user_data",demo); // demo data -> "user_data"

  fig.immediate_drawing = "on";
  fig.visible = "on";

  // restore default figure();
  sdf(); 
  
endfunction


// -------------------------------------------------------------
// creation of list of choices
// => "handle" to the list
// -------------------------------------------------------------
function [h] = CL__demos_createListe(fig, titre, cadre, tag)

  // frame
  uicontrol( ...
  "parent"              , fig,...
  "relief"              , "groove",...
  "style"               , "frame",...
  "units"               , "pixels",...
  "position"            , cadre,...
  "horizontalalignment" , "center", ...
  "background"          , [1 1 1], ...
  "visible"             , "on", ...
  "tag"                 , "frame");

  // Frame title
  margey = 3;
  htxt = uicontrol( ...
  "parent"              , fig,...
  "style"               , "text",...
  "string"              , "",...
  "units"               , "pixels",...
  "position"            , [ cadre(1), cadre(2)+cadre(4)+margey-2, cadre(3), 20],...
  "fontunits"           , "points",...
  "fontSize"            , 11,...
  "fontWeight"          , "normal",...
  "horizontalAlignment" , "center", ...
  "background"          , [1 1 1], ...
  "visible"             , "on", ...
  "tag"                 , "title_frame");

  // List Box
  margex = 6;
  margey = 6;

  h = uicontrol( ...
  "parent"              , fig,...
  "style"               , "listbox",...
  "units"               , "pixels",...
  "position"            , [ cadre(1)+margex cadre(2)+margey cadre(3)-2*margex cadre(4)-2*margey ],...
  "fontunits"           , "points",...
  "fontSize"            , 12,...
  "relief"              , "flat",... 
  "horizontAlalignment" , "left", ...
  "BackgroundColor"     , [255/255 , 255/255 , 255/255 ], ...
  "callback"            , "CL__demos_cb(1)",...
  "visible"             , "on", ...
  "tag"                 , tag);

  // title again ! (because of scilab bug in previous versions)
  set(htxt, "string", titre); 
  
endfunction


// -------------------------------------------------------------
// Logo
// -------------------------------------------------------------
function [h] = CL__demos_createLogo(fig,nomfic,cadre, dimx, dimy)

  str = "<html>";
  str = str + "<img src=""file:///" + nomfic + """";
  str = str + " width=" + msprintf("%d",dimx);
  str = str + " height=" + msprintf("%d",dimy);
  str = str + " alt=""CelestLab"" />";
  str = str + "</html>";

  h = uicontrol( ...
  "parent"              , fig,...
  "style"               , "text",...
  "string"              , str,...
  "units"               , "pixels",...
  "position"            , cadre,...
  "background"          , [1 1 1], ...
  "tag"                 , "my_text", ...
  "horizontalalignment" , "center", ...
  "verticalalignment"   , "middle" ...
  );

endfunction

// -------------------------------------------------------------
// creation of checkbox
// => "handle" of the checkbox
// -------------------------------------------------------------
function [h] = CL__demos_createCheckbox(fig, titre, cadre, tag)

  h = uicontrol( ...
  "parent"              , fig,...
  "style"               , "checkbox",...
  "string"              , titre,...
  "units"               , "pixels",...
  "position"            , cadre,...
  "background"          , [1 1 1], ...
  "foregroundColor"     , [0 0 0], ...
  "tag"                 , tag, ...
  "callback"            , "CL__demos_cb(1)",...
  "horizontalalignment" , "left", ...
  "verticalalignment"   , "bottom" ...
  );

endfunction


// -------------------------------------------------------------
// lists ".sce" files in sub-directories of "path" 
// topics : list of sub-directories (1st level)
// contents : list of "tlist(filename, filepaths)"
// -------------------------------------------------------------
function [topics, contents] = CL__demos_gen_data(path)

 topics = [];
 contents = list();

 // Code:
 listed = gsort(listfiles(path), 'lr', 'i'); // liste des sous-repertoires du repertoire 'demos'

 for d = listed'
   nomrep = fullfile(path,d);
   if isempty(strindex(d,'.')) & length(findfiles(nomrep, "*.sce")) <> 0
      topics = [topics ; strsubst(d,"_", " ")];

      fics = nomrep + filesep() + gsort(findfiles(nomrep,"*.sce"), 'lr', 'i');
      noms = basename(fics);

      cont = tlist(["contents", "noms", "fics"], strsubst(noms,"_", " "), fics);
      contents = lstcat(contents, list(cont));
   end
 end

endfunction



