//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

//  Demo tool for CelestLab
//  Author: A. Lamy

// -------------------------------------------------------------
// all "call-backs" for CL__demos: 
// 1 => lists
// 2 => quit
// 4 => options
// 5 => help
// 6 => look-for
// -------------------------------------------------------------
function CL__demos_cb(numcb)
  if (numcb == 1)
    CL__demos_cb_list();
  elseif (numcb == 2)
    CL__demos_cb_quit();
  elseif (numcb == 4)
    CL__demos_cb_options();
  elseif (numcb == 5)
    CL__demos_cb_help();
  elseif (numcb == 6)
    CL__demos_cb_find();
  elseif (numcb == 7)
    CL__demos_cb_findfct();
  else
    // nothing
  end
endfunction


// -------------------------------------------------------------
// "call-back" for the lists
// -------------------------------------------------------------
function CL__demos_cb_list()

  // get 'demo' structure (gcbo = calling object)
  fig = get(gcbo, "parent"); 

  demo = get(fig, "user_data"); // internal data
  tag = get(gcbo,"tag"); // tag of calling object

  // does nothing if other callback function active
  if (demo.cb_actif == 1); 
    return; 
  end 

  demo.cb_actif = 1; // inhibits other callbacks activations
  set(fig,"user_data",demo); // update data

  keep = get(demo.h3, "value");
  view = get(demo.h4, "value");
  editd = get(demo.h5, "value");
  debug_mode = demo.db_mode;

  if (tag == "liste2" & keep == 0 & editd <> 1)
     for k = 1:length(demo.listfen);
        f = demo.listfen(k);
        try, delete(f), end
     end
     demo.listfen = list();
  end

  scf_save = scf;
  funcprot(0);  // prevent warning as scf is redefined

 // redefinition of scf : 
 // - stores the figure id
 // - initializes the default event handler
 // - NB : initializes user_data as a structure with 2 fields: 
 //        -> eventHandler : name of event handler function
 //        -> PointerLocationData : reference information for slope
 function [f] = scf(varargin)
   rhs=argn(2);
   if (rhs == 0)
     demo = get(fig, "user_data");
     f = scf_save();
     f.axes_size = [630,420];
     demo.listfen(length(demo.listfen)+1) = f;
     set(fig,"user_data",demo);

     ud = struct();
     ud.eventHandler = ""; 
     ud.PointerLocationData = [];
     set(f, 'user_data', ud);
     f.event_handler = "CL__demos_userHandler";
     f.event_handler_enable = "off";

   else
     f = scf_save(varargin(1));
   end
 endfunction

  // script execution
  function [ierr] = exec_script(nomfic)
    oldfmt=format(); // save format for string()
    format('v', 10); // 10 digits
    CL_init(init_glob = %f); // initialisation des constantes au cas ou
    ierr = exec(nomfic, 'errcatch', -1);
    if (ierr <> 0)
       [str,n,lig,func] = lasterror(); // derniere erreur
       if (debug_mode == "ON" & ~isempty(str))
          mfprintf(%io(2), "*** STOP ***\n");
          for (k = 1:size(str,"*"))
             mfprintf(%io(2), "=> Message: %s\n",str(k)); 
          end
          if (func <> ""); mfprintf(%io(2), "=> Function: \n%s\n", func); end
       elseif (~isempty(str) & grep(str, "*** CelestLab: Cancelled") == [])
          messagebox(str, "Error", "error")
       end
    end
    format(oldfmt(2), oldfmt(1)); // restore format
  endfunction

  // print info if available
  // info file = same name as script (but .info instead of .sce)
  function disp_info(nomfic)
    try
      lignes = mgetl(nomfic);
    catch
      lignes = [];
    end
    if isempty(lignes); return; end
    mprintf("\nInfo:\n");
    w = 0;
    infoex = %f;
    for k = 1:length(length(lignes))
      if (length(lignes(k)) <= 3); continue; end
      lig1 = strstr(lignes(k), '//>');
      if (length(lig1) == 0); continue; end
      lig = strstr(lig1, '>');
      infoex = %t;
      mprintf("%s\n", lig);
    end
    if (~infoex); mprintf("None\n"); end
  endfunction

  if (tag == "liste1")
     demo.numtopic = get(gcbo, "value"); // affecte la liste des applis
     appli = demo.contents(demo.numtopic).noms;
     set(demo.h2, "string", strcat(appli(:,1),"|"));
     set(demo.h2, "user_data", appli);
     demo.numchoix = 0; // pas d'appli courante

  elseif (tag == "liste2")
     demo.numchoix = get(gcbo, "value");
     nomchoix = demo.contents(demo.numtopic).noms(demo.numchoix); 
     nomfic = demo.contents(demo.numtopic).fics(demo.numchoix); // nom du script

     if (editd == 1)
       try
         scinotes(nomfic, "readonly"); 
       end
       demo = get(fig, "user_data"); // get again in case of changes
       set(demo.h1, "value", demo.numtopic); // force selected numbers
       set(demo.h2, "value", demo.numchoix);
       set(demo.h2, "value", 0); // remove selection
     
     else
     
     scf(fig);
     fig.info_message = nomchoix + ": in progress...";
    
     set(fig,"user_data",demo); // car modifie par scf()

     if (view == 1)
        mprintf("\n");
        mprintf("-------------------------------------------\n");
        mprintf("Script path:\n");
        script_path = nomfic; 
        if (getos() == "Windows")
          script_path = getlongpathname(script_path); 
        end
        mprintf("%s\n", script_path);
        disp_info(nomfic);
        deff('$I(str)', 'mprintf(''%s\n'', str)');
        mprintf("-------------------------------------------\n");
     end

	 // all figures are created invisible
	 sdf(); // reset default figure
	 g = gdf(); // default figure
	 g.visible = "off"; 
     ierr = exec_script(nomfic);
	 sdf(); // reset default figure
	 
     demo = get(fig, "user_data"); // get again in case of changes
     set(demo.h1, "value", demo.numtopic); // force selected numbers
     set(demo.h2, "value", demo.numchoix);
     set(demo.h2, "value", 0); // remove selection

     scf(fig);
     fig.info_message = " ";
   end

  elseif (tag == "keep")
     value = get(demo.h3, "value");
  end

  demo.cb_actif = 0;
  set(fig,"user_data",demo);

endfunction

// -------------------------------------------------------------
// "quit" call-back
// -------------------------------------------------------------
function CL__demos_cb_quit()
  // closes all open windows

  fig = get(get(gcbo, "parent"),"parent");
  demo = get(fig, "user_data");

  for k = 1:length(demo.listfen);
    f = demo.listfen(k);
    try
      delete(f);
    end
  end

  delete(fig);
endfunction


// -------------------------------------------------------------
// "options" call-back 
// -------------------------------------------------------------
function CL__demos_cb_options()
  DEBUG_MODES = ["ON", "OFF"]; 
  SEARCH_DOMAINS = ["TEXT", "SCRIPT"]; 
  
  fig = get(get(gcbo, "parent"),"parent");
  demo = get(fig, "user_data");

  val1 = find(demo.db_mode == DEBUG_MODES);
  if (val1 <> 1 & val1 <> 2); val1 = 1; end  

  val2 = find(demo.find_opt == SEARCH_DOMAINS);
  if (val2 <> 1 & val2 <> 2); val2 = 1; end  
  
  l1 = list(' Debug mode: ', val1, DEBUG_MODES);
  l2 = list(' Search domain: ', val2, SEARCH_DOMAINS);
  k = x_choices("Options: ", list(l1, l2));

  if (~isempty(k))
    demo.db_mode = DEBUG_MODES(k(1));
    demo.find_opt = SEARCH_DOMAINS(k(2));
    set(fig,"user_data", demo);
  end
endfunction


// -------------------------------------------------------------
// "help" call-back
// -------------------------------------------------------------
function CL__demos_cb_help()
  // path to demos directory
  path = fullfile(CL_home(), "demos"); 
  if (getos() == "Windows"); path = getlongpathname(path); end

  msg = [
    "Select an item in the ''Topics'' list first, then an ''application''."
    " "
    "Each application corresponds to a specific script (''.sce'')"
    "in the CelestLab ''demos'' directory."
    "The ''demos'' root path is: "
    path
    " "
    "Special features: "
    " "
    " - Keep Plots: "
    "   If selected, graphic windows are not deleted"
    "   when a new application is selected."
    " "
    " - Show Info:"
    "   If selected, additional information is printed. "
    "   (script path + any additional information "
    "   present in the script)"
    " "
    " - Edit:"
    "   If selected, the demo source file is edited in "
    "   read-only mode (and the demo is not executed). "
    " "
    " - Debug mode: (""Options"" menu)"
    "   If ''ON'', error messages are printed in the console, if any. "
    "   Default is ''OFF''."
    " "
    " - Find a demo: (""Help"" menu)"
    "   Enable selecting demo files containing specific keywords. "
    "   - keywords on same line => OR"
    "   - keywords on two or more lines => AND"
    "   Looked-for keywords should be composed of alphanumeric characters "
    "   only (including ""_"" and ""-"").  Other characters are ignored. " 
    "  Available options: (""Options"" menu)" 
    "  - TEXT: Description text: look for keywords in the description text only. "
    "  - SCRIPT: Whole script: look for keywords in the entire script. "
    " "
    " "
    "Note: "
    " The CelestLab demo tool calls CL_init before executing the scripts. "
    " It follows that changing some of the values of the "
    " local variables %CL_xxx has no impact on the demo results."
    "------------------------------------------------------------------------- "
  ];

  messagebox(msg, "CelestLab Demo Tool - Help", "info")

endfunction


// -------------------------------------------------------------
// "find a demo" call-back
// -------------------------------------------------------------
function CL__demos_cb_find()

  // look for all keywords in all demo files
  // path_demos: string, 1x1
  // fnames: string, 1xN
  // list_kw: list of (array 1xN of string)
  // opt => "TEXT" or "SCRIPT"
  // result: string Px1
  function [result] = demo_find(path_demos, fnames, list_kw, opt)
    result = []; 
    if (size(list_kw) == 0)
      return; 
    end 
    
    // look for keywords (AND)
    // txt: string (Px1): text where to look for
    // kws: string (1xN)
    function [found] = demo_find_kw(txt, kws)
      found = %t; 
      for (kw = kws)
        I = grep(txt, kw);
        if (I == [])
          found = %f; 
          break;
        end
      end
    endfunction 

    // look for keywords (OR)
    // txt: string (Px1): text where to look for
    // list_kw: list of (array 1xN of string)
    function [found] = demo_find_kws(txt, list_kw)
      found = %f; 
      for (elem_kw = list_kw)
        if (demo_find_kw(txt, elem_kw))
          found = %t; 
          break; 
        end
      end
    endfunction 
        
    for fname = fnames
      fnamerel = getrelativefilename(path_demos, fname); 
      txt = mgetl(fname); 
      if (opt == "TEXT")
        // limit to description text (lines beginning with "//>") 
        I = find(part(txt, 1:3) == "//>"); 
        txt = txt(I); 
      end
      txt = convstr([txt; fnamerel], "u"); 
            
      if (demo_find_kws(txt, list_kw))   
        demo = tokens(fnamerel, ["\", "/"]); 
        demo = strsubst(demo, "_", " "); 
        demo = strsubst(demo, ".sce", ""); 
        demo = strcat(demo, " -> ");  
        result = [result; demo]; 
      end
    end
  
  endfunction

  // generate list of keywords to look for 
  // mat_kw: (string) Nx1: result of "x_dialog" function
  // list_kw: list of array 1xN of string 
  function [list_kw] = demo_genlistkw(mat_kw)
    list_kw = list(); 

    for k = 1 : size(mat_kw, "*")
      str = convstr(mat_kw(k), "u"); 
      // keep alphanums or "_" or "-" only
      codes = ascii(str);
      I = find(~isalphanum(str) & codes <> ascii("_") & codes <> ascii("-")); 
      codes(I) = ascii(" "); 
      // tokens (separator = 1 or more " ")
      kws = tokens(ascii(codes)); 
      if (kws <> [])
        list_kw($+1) = matrix(kws, 1, -1); 
      end
    end
    
  endfunction

  // generate title for message window (logical expression) 
  function [txt] = demo_genexprkw(list_kw)
    str = []; 
    for k = 1 : size(list_kw)
      if (size(list_kw(k), "*") > 1)
        str(k) = strcat(list_kw(k), " and "); 
        if (size(list_kw) > 1); str(k) = "(" + str(k) + ")"; end
      else
        str(k) = list_kw(k); 
      end
    end
    txt = strcat(str, " or "); 
    if (txt == ""); txt = "?"; end
  endfunction
    
  // ----------------
  // MAIN
  // ----------------
  fig = get(get(gcbo, "parent"), "parent");
  demo = get(fig, "user_data");
  find_opt = demo.find_opt; // "TEXT" or "SCRIPT"

  path_demos = fullfile(CL_home(), "demos"); 
  fnames = CL_path("*.sce", path_demos, "all"); 

  header = [ "Keywords ? "; ...
             "- on same line => AND"; ...
             "- on two or more lines => OR"; ...
             " "; ... 
             "Search domain: " + find_opt; ... 
             "See Edit->Options for available options" ]; 
  mat_kw = x_dialog(header, ["?"; ""; ""; ""; ""]); 

  // cancel button pressed
  if (mat_kw == [])
    return; 
  end
  
  // gen list and find matching demos 
  list_kw = demo_genlistkw(mat_kw); 
  result = demo_find(path_demos, fnames, list_kw, find_opt); 

  // message box 
  if (result == []); result = "None"; end
  txt = ["Demos matching:"; demo_genexprkw(list_kw); " "; result]; 
  msg_title = "CelestLab Demo Tool"; 
  messagebox(txt, msg_title, "info", "OK"); 

endfunction


// -------------------------------------------------------------
// "find a function" call-back
// -------------------------------------------------------------
function CL__demos_cb_findfct()

  function [data] = demo_list_fct(fnames)
    data = []; 

    function [ret] = isalnum(codes)
      // Note: 
      // special characters (accents) return 2 codes
      // but the second number is not ascii => will be eliminated 
      ret = ((codes >= ascii("a") & codes <= ascii("z")) | ...
      (codes >= ascii("A") & codes <= ascii("Z")) | ...
      (codes >= ascii("0") & codes <= ascii("9")))
    endfunction
  
    for fname = fnames
      txt = stripblanks(mgetl(fname), %t); 
      // remove comment lines
      I = find(part(txt, 1:2) <> "//" & txt <> ""); 
      txt = txt(I); 
      // remaining comments
      I = grep(txt, "//"); 
      for k = I
        J = strindex(txt(k), "//"); 
        txt(k) = part(txt(k), 1:(J(1)-1)); 
      end
      str = strcat(txt, " "); 

      codes = ascii(str);
      I = find(~isalnum(codes) & codes <> ascii("_") & codes <> ascii("%")); 
      codes(I) = ascii(" "); 
      tok = tokens(ascii(codes)); 
      I = find(part(tok, 1:3) == "CL_"); 
      tok = tok(I); 
      
      names = repmat(fname, size(tok, "*"), 1); 
      data = [data; [tok, names]]; 
    end
    
    // only existing CelestLab function selected
    I = find(isdef(data(:,1))); 
    data = data(I,:); 
  
  endfunction
  
  function [res] = demo_select_res(data, fctname, path_demos)
  
    I = find(data(:,1) == fctname); 
    fnames = matrix(unique(data(I,2)), 1, -1); 

    res = []; 
    for fname = fnames; 
      demo = getrelativefilename(path_demos, fname); 
      demo = tokens(demo, ["\", "/"]); 
      demo = strsubst(demo, "_", " "); 
      demo = strsubst(demo, ".sce", ""); 
      demo = strcat(demo, " -> ");  
      res = [res; [demo, fname]]; 
    end
    
  endfunction

 
  // ----------------
  // MAIN
  // ----------------
  path_demos = fullfile(CL_home(), "demos"); 
  fnames = CL_path("*.sce", path_demos, "all"); 
  
  data = demo_list_fct(fnames); 
  fctnames = unique(data(:,1)); 
  k = x_choose(fctnames, "CelestLab functions used:"); 

  if (k <> 0 & k <> [])
    fctname = fctnames(k); 
    result = demo_select_res(data, fctname, path_demos); 
    if (result == []); result = "None"; end // unlikely! 
    txt = ["Demos using: " + fctname; " "; result(:,1)]; 
    msg_title = "CelestLab Demo Tool"; 
    messagebox(txt, msg_title, "info", "OK"); 
  end

endfunction



