//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

// Displays CelestLab menu 
// Note: CelestLab menu is a handle with the tag: "__CELESTLAB_MENU__"
// (this tag should not be used in Scilab) 
function CL__menu()

  CL_MENU_TAG = "__CELESTLAB_MENU__"; 

  function [desc] = menu_desc()
    // menu description: 
    // [ [label, callback]; ... ]
    // callback = BEGIN/END => sub-menu
    
    // Part of menu (data files)
    data_dir = fullfile(CL_home(),"data");
    lfiles = CL_path("*.scd", data_dir, "all");
    datafiles_labels = strsubst(strsubst(lfiles, data_dir + filesep(), ""), filesep(), " / ");
    datafiles_actions = "CL__editDataFile(''" + lfiles + "'')";
    menu_data_files = [datafiles_labels', datafiles_actions']; 

    
    // utilities: HDF5 files for Scilab 6
    menu_utilities1 = []; 
    if (CL__scilabVersion() >= 540 & CL__scilabVersion() < 600)
      menu_utilities1 = [ ..
        ["Manage data files for Scilab6", "BEGIN"]; ..
        ["Create binary data files for Scilab6 ...", "CL__genHDF5DataFiles(1)"]; ..
        ["Remove binary data files for Scilab6 ...", "CL__genHDF5DataFiles(-1)"]; ..
        ["Manage data files for Scilab6", "END"] ..
      ]
    end
    
    // utilities: validation tools (only if not "official" version)
    menu_utilities2 = []; 
    cl_version = CL_version("num");
    if (cl_version(4) <> 0)
      menu_utilities2 = [ ..
        ["Run", "BEGIN"]; ..
        ["Tests", "CL__execTests()"]; ..
        ["Coverage", "CL__execTestsCov()"]; ..
        ["Examples", "CL__execExamples()"]; ..
        ["Cookbook", "CL__execCookbook()"]; ..
        ["Run", "END"] ..
      ]
    end
    
    menu_utilities = [menu_utilities1; menu_utilities2]; 
    if (menu_utilities == []); menu_utilities = ["None", ""]; end

    desc = [ 
      [ "Demos", "CL__demos()"];  ..
      // Note: "CelestLab" : name of XML page
      [ "Help", "CL__help(''CelestLab'')"]; .. 
      [ "Data files", "BEGIN"]; ..
      [ menu_data_files ]; ..
      [ "Data files", "END"]; ..
      [ "Utilities", "BEGIN"]; ..
      [ menu_utilities ]; ..
      [ "Utilities", "END"]; ..
      [ "---", ""];  ..
      [ "Release notes", "BEGIN"]; ..
      [ "Latest version", "CL__releaseNotes(1)"]; ..
      [ "Previous versions", "CL__releaseNotes(2)"]; ..
      [ "Release notes", "END"]; ..
      [ "Edit configuration file", "CL__editConfigFile()"]; ..
      [ "About CelestLab", "CL__about()"] ..
    ]; 
    
  endfunction
  
  
  // fill CelestLab menu 
  // h_menu: root of CelestLab menu (menu handle)
  // desc : menu description 
  function menu_fill(h_menu, desc)
  
    handles = [h_menu]; 
    level = 1; 
    
    for k = 1 : size(desc, 1)
      parent = handles(level); 
      label = desc(k,1); 
      cb = desc(k,2); 

      if (cb == "BEGIN")
        // start sub menu
        h = uimenu("parent", parent, "label", label); 
        handles = [handles(1:level), h]; 
        level = level + 1; 
        
      elseif (cb == "END")
        // end sub menu
        level = level - 1; 
        
      else
        // new entry at current level
        h = uimenu("parent", parent, "label", label); 
        set(h, "callback", cb); 
      end
      
    end
    
  endfunction
  

  // delete main menu in case
  // try/catch added for Scilab 6.1.1 (bug) 
  try
    h_menu = findobj("tag", CL_MENU_TAG); 
  catch 
    h_menu = []; 
  end 
  if (h_menu <> [])
    delete(h_menu); 
  end
  
  // create main menu
  h_menu = uimenu("parent", 0, "tag", CL_MENU_TAG, "label", "CelestLab"); 
  
  // fill main menu
  desc = menu_desc(); 
  menu_fill(h_menu, desc); 
   
endfunction
