//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function CL__help(key)
// Help function 
//
// Calling Sequence
// CL__help()
// CL__help(key)
//
// Description
// <itemizedlist>
// <listitem>
// <p>Displays help pages in the Scilab help browser. </p>
// <p>This function has been introduced for compatibility reasons, as the 
// "help" function name has changed as of Scilab 2025.0.0. </p>
// </listitem>
// </itemizedlist>
//
// Parameters
// key: (string, optional) The requested help page or pattern.
//
// Authors
// CNES
//
// Examples
// // Open help page
// CL__help()
//
// // Search "Celestlab" keyword in the help page
// CL__help("Celestlab")
//
// 

if (~exists("key", "local"))
  key = []; 
end 
  
// Function to be use as help depends on Scilab version:
// - Scilab 2025.0.0 or higher : "doc"
// - Scilab 2024.1.0 or lower : "help"
if (CL__scilabVersion() >= 202500) 
  fct_help = doc; 
else
  fct_help = help; 
end 

// Call of the help function
if (key == [])
  fct_help(); 
else
  fct_help(key); 
end 

endfunction 
