//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [varargout] = CL_fileparts(fullpath, sel)
// Path, filename, extension of a file path  
//
// Calling Sequence
// [path, fname, extension] = CL_fileparts(fullpath)
// value = CL_fileparts(fullpath, sel)
//
// Description
// <itemizedlist><listitem>
// <p>Returns the path, filename, extension of a file path.</p>
// <p></p>
// <p><b>Note</b>:</p>
// <p>Same as filepath, except that the separator at the end of the 
// full path is ignored if it exists.</p>
// <p></p>
// </listitem>
// </itemizedlist>
//
// Parameters
// fullpath: (string) Full path. (1xN)
// sel: (string, optional) selection : "path", "fname" or "extension". (1x1)
// path: (string) Path of directory (1xN) 
// name: (string) Name of file (1xN)
// extension: (string) Extension of the file (1xN)
//
// Authors
// CNES - DCT/SB
//
// Examples
// // Elements of a file paths 
// [path, fname, ext] = CL_fileparts("directory/readme.txt")
//
// // Directory part  
// path = CL_fileparts("directory/name", "path") 
// path = CL_fileparts("directory/name/", "path") // => same 
//

// =============================================
// MAIN
// =============================================
nbargs = argn(2); 

if (nbargs == 0)
  CL__error("Invalid number of arguments"); 
  
else
  // remove possible separator at the end of the path 
  fullpath = pathconvert(fullpath, %f, %f); 
  if (nbargs < 2) 
    [path, fname, extension] = fileparts(fullpath); 
    varargout(1) = path; 
    varargout(2) = fname; 
    varargout(3) = extension; 
    
  else 
    varargout(1) = fileparts(fullpath, sel); 
  end 
end 

endfunction
