//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [f] = CL_g_getFigureHandle(num)
// Get figure handle
//
// Calling Sequence
// f = CL_g_getFigureHandle(num)
//
// Description
// <itemizedlist>
// <listitem>
// <p>Figure handle associated with figure number.</p>
// <p>The function returns the figure handle associated with figure number <b>num</b>, or [] if 
// the figure does not exist. </p>
// <p></p>
// </listitem>
// <listitem>
// <p><b>Note</b>:</p>
// <p>This function has been added for Scilab 6.1.0 as the equivalent Scilab function
// get_figure_handle is deprecated and the proposed replacement: 
// findobj("figure_id", num) is much slower.  </p>
// </listitem>
// </itemizedlist>
//
// Parameters
// num: (integer) Figure number. (1x1) 
// f: Corresponding figure handle. 
//
// Authors
// CNES - DCT/SB (AL)
//
// Examples
// num = 99; 
// scf(num); 
// f = CL_g_getFigureHandle(num); 
// f.figure_id

// Declarations:


// Code:

if (argn(2) <> 1)
  CL__error("Invalid number of input arguments (1 expected)"); 
end

if (size(num, "*") <> 1)
  CL__error("Invalid size of input arguments (1x1 expected)"); 
end

if (find(winsid() == num) == [])
  f = []; 
  
else
  g = get("current_figure"); 
  set("current_figure", num);
  f = get("current_figure");
  set("current_figure", g);
end

endfunction
