//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.


function [num] = CL_scilabVersion()
// Scilab version as a number
//
// Calling Sequence
// [num] = CL_scilabVersion()
//
// Description
// <itemizedlist>
// <listitem>
// <p>Returns the version of Scilab as a number.  </p>
// <p></p>
// <p>Examples: </p>
// <p>- Version 6.0.2 => 602 </p>
// <p>- Version 2023.1.0 => 202310. </p>
// <p></p></listitem>
// <listitem>
// <b>Notes</b>: 
// <p>- For efficiency reasons, the version number is precomputed 
// and initilized when CL__configInit is called (in start-up file). </p>
// </listitem></itemizedlist>
//
// Parameters
// num: (integer) Scilab version number.
//
// Authors
// CNES - DCT/SB
//
// Examples
// if (CL_scilabVersion() >= 202300)
//   disp("Scilab version is >= 2023.0.0"); 
// else
//   disp("Scilab version is < 2023.0.0"); 
// end 

// Declarations: 
global %CL__PRIV;

// %CL__PRIV is supposed already initialized 
num = %CL__PRIV.SCILAB_VERSION; 
  
endfunction
