//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [v1, v2] = CL_op_rarp2vavp(r1, r2, mu)
// Apoapsis/periapsis radius to Apoapsis/periapsis velocity (elliptic orbits) - DEPRECATED
//
// Calling Sequence
// [v1, v2] = CL_op_rarp2vavp(r1, r2 [, mu])
//
// Description
// <itemizedlist>
// <listitem>
// <p>This function is deprecated. </p>
// <p>Replacement function: <link linkend="CL_kp_apsConvert">CL_kp_apsConvert</link></p>
// <p>Use 'CL_kp_apsConvert("ra", ra, "rp", rp, ["va", "vp"])' instead of 'CL_op_rarp2vavp(ra, rp)'.</p>
// <p></p></listitem>
// <listitem>
// <p>Computes velocity at apoapsis and periapsis from 
// apoapsis and periapsis radii (elliptic orbits only).</p>
// <p></p></listitem>
// <listitem>
// <p><b>Note:</b></p>
// <p>[v1, v2] = CL_op_rarp2vavp(r1, r2, mu) gives the same results (same v1 and v2) as 
// [v2, v1] = CL_op_rarp2vavp(r2, r1, mu)</p>
// </listitem>
// </itemizedlist>
//
// Parameters
// r1: Radius at position 1 (apoapsis or periapsis). [m] (1xN or 1x1)
// r2: Radius at position 2 (periapsis or apoapsis). [m] (1xN or 1x1)
// mu: (optional) Gravitational constant. Default: %CL_mu. [m^3/s^2] (1x1)
// v1: velocity at position 1. [m/s] (1xN)
// v2: velocity at position 2. [m/s] (1xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL_kp_apsConvert
// CL_op_rava2ae
// CL_op_rpvp2ae
//
// Examples
// ra = 7178.e3;
// rp = 7078.e3;
// [va, vp] = CL_op_rarp2vavp(ra, rp)
// [vp, va] = CL_op_rarp2vavp(rp, ra)

// Declarations:

// Code:
CL__warnDeprecated(); // deprecated function

if (~exists("mu", "local")); mu = CL__dataGetEnv("mu"); end

N = size(r1, 1); 
[r1, r2] = CL__checkInputs(r1, N, r2, N); 

if (find(r1 <= 0 | r2 <= 0) <> [])
  CL__error("Invalid arguments (should be positive)"); 
end

// Note : ecc as computed may be negative (!) in order to have 
// r1 <-> v1 and r2 <-> v2
sma = (r1 + r2) / 2; 
ecc = (r1 - r2) ./ (r1 + r2); 

v1 = sqrt(mu ./ sma) .* sqrt((1 - ecc) ./ (1 + ecc)); 
v2 = sqrt(mu ./ sma) .* sqrt((1 + ecc) ./ (1 - ecc)); 

endfunction
